from agentmake import AGENTMAKE_USER_DIR
from pathlib import Path
import os

AGENTMAKE_CONFIG = {
    "print_on_terminal": False,
    "word_wrap": False,
}
OLLAMA_NOT_FOUND = "`Ollama` is not found! BibleMate AI uses `Ollama` to generate embeddings for semantic searches. You may install it from https://ollama.com/ so that you can perform semantic searches of the Bible with BibleMate AI."
BIBLEMATEDATA = os.path.join(AGENTMAKE_USER_DIR, "biblemate", "data")
if not os.path.isdir(BIBLEMATEDATA):
    Path(BIBLEMATEDATA).mkdir(parents=True, exist_ok=True)
def fix_string(content):
    return content.replace(" ", " ").replace("‑", "-")


agent_mode=False
prompt_engineering=False
max_steps=30
lite=True
hide_tools_order=True
default_bible="NET"
default_commentary="CBSC"
default_encyclopedia="ISB"
default_lexicon="Morphology"
max_semantic_matches=15
max_log_lines=2000
mcp_port=33333
embedding_model="paraphrase-multilingual"
disabled_tools=[]